# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpc_stubs/device_agent.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dgrpc_stubs/device_agent.proto\x12\x0c\x64\x65vice_agent\"/\n\rRequestHeader\x12\x13\n\x06\x61pp_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_app_id\"\xae\x01\n\x0eResponseHeader\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x14\n\x0c\x63loud_synced\x18\x02 \x01(\x08\x12\x13\n\x0b\x63loud_ready\x18\x05 \x01(\x08\x12\x1a\n\rresponse_code\x18\x03 \x01(\x05H\x00\x88\x01\x01\x12\x1d\n\x10response_message\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\x10\n\x0e_response_codeB\x13\n\x11_response_message\"^\n\x0eMessageDetails\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0f\n\x07payload\x18\x03 \x01(\t\x12\x11\n\ttimestamp\x18\x04 \x01(\t\"L\n\x0e\x43hannelDetails\x12\x14\n\x0c\x63hannel_name\x18\x01 \x01(\t\x12\x16\n\taggregate\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_aggregate\"d\n\x0c\x41gentDetails\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\x12\x12\n\nagent_name\x18\x02 \x01(\t\x12.\n\x08\x63hannels\x18\x03 \x03(\x0b\x32\x1c.device_agent.ChannelDetails\"P\n\x10TestCommsRequest\x12+\n\x06header\x18\x02 \x01(\x0b\x32\x1b.device_agent.RequestHeader\x12\x0f\n\x07message\x18\x01 \x01(\t\"\\\n\x11TestCommsResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.device_agent.ResponseHeader\x12\x10\n\x08response\x18\x02 \x01(\t\"X\n\x15MessageDetailsRequest\x12+\n\x06header\x18\x02 \x01(\x0b\x32\x1b.device_agent.RequestHeader\x12\x12\n\nmessage_id\x18\x01 \x01(\t\"\x8f\x01\n\x16MessageDetailsResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.device_agent.ResponseHeader\x12\x32\n\x07message\x18\x02 \x01(\x0b\x32\x1c.device_agent.MessageDetailsH\x00\x88\x01\x01\x42\n\n\x08_message\"Z\n\x15\x43hannelDetailsRequest\x12+\n\x06header\x18\x02 \x01(\x0b\x32\x1b.device_agent.RequestHeader\x12\x14\n\x0c\x63hannel_name\x18\x01 \x01(\t\"\x8f\x01\n\x16\x43hannelDetailsResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.device_agent.ResponseHeader\x12\x32\n\x07\x63hannel\x18\x02 \x01(\x0b\x32\x1c.device_agent.ChannelDetailsH\x00\x88\x01\x01\x42\n\n\x08_channel\"_\n\x1a\x43hannelSubscriptionRequest\x12+\n\x06header\x18\x02 \x01(\x0b\x32\x1b.device_agent.RequestHeader\x12\x14\n\x0c\x63hannel_name\x18\x01 \x01(\t\"\xd4\x01\n\x1b\x43hannelSubscriptionResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.device_agent.ResponseHeader\x12\x32\n\x07\x63hannel\x18\x02 \x01(\x0b\x32\x1c.device_agent.ChannelDetailsH\x00\x88\x01\x01\x12\x32\n\x07message\x18\x03 \x01(\x0b\x32\x1c.device_agent.MessageDetailsH\x01\x88\x01\x01\x42\n\n\x08_channelB\n\n\x08_message\"\xb7\x01\n\x13\x43hannelWriteRequest\x12+\n\x06header\x18\x05 \x01(\x0b\x32\x1b.device_agent.RequestHeader\x12\x14\n\x0c\x63hannel_name\x18\x01 \x01(\t\x12\x17\n\x0fmessage_payload\x18\x02 \x01(\t\x12\x15\n\x08save_log\x18\x03 \x01(\x08H\x00\x88\x01\x01\x12\x14\n\x07max_age\x18\x04 \x01(\x05H\x01\x88\x01\x01\x42\x0b\n\t_save_logB\n\n\x08_max_age\"?\n\x10\x44\x65\x62ugInfoRequest\x12+\n\x06header\x18\x01 \x01(\x0b\x32\x1b.device_agent.RequestHeader\"a\n\x14\x43hannelWriteResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.device_agent.ResponseHeader\x12\x12\n\nmessage_id\x18\x02 \x01(\t\"m\n\x11\x44\x65\x62ugChannelState\x12\x14\n\x0c\x63hannel_name\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x02 \x01(\x08\x12\x18\n\x10local_updated_at\x18\x03 \x01(\x02\x12\x18\n\x10\x63loud_updated_at\x18\x04 \x01(\x02\"s\n\x13\x44\x65\x62ugPendingMessage\x12\x14\n\x0c\x63hannel_name\x18\x01 \x01(\t\x12\x0f\n\x07\x61pp_key\x18\x02 \x01(\t\x12\x10\n\x08save_log\x18\x03 \x01(\x08\x12\x0f\n\x07payload\x18\x04 \x01(\t\x12\x12\n\npublish_in\x18\x05 \x01(\x05\"\xb5\x02\n\x11\x44\x65\x62ugInfoResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.device_agent.ResponseHeader\x12\x18\n\x10\x61\x63tive_callbacks\x18\x02 \x03(\t\x12\x15\n\rwss_callbacks\x18\x03 \x03(\t\x12\x16\n\x0ewss_aggregates\x18\x04 \x03(\t\x12\x19\n\x11wss_subscriptions\x18\x05 \x03(\t\x12\x31\n\x08\x63hannels\x18\x06 \x03(\x0b\x32\x1f.device_agent.DebugChannelState\x12;\n\x10pending_messages\x18\x07 \x03(\x0b\x32!.device_agent.DebugPendingMessage\x12\x15\n\rwss_connected\x18\x08 \x01(\x08\"B\n\x13TempAPITokenRequest\x12+\n\x06header\x18\x01 \x01(\x0b\x32\x1b.device_agent.RequestHeader\"\x83\x01\n\x14TempAPITokenResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.device_agent.ResponseHeader\x12\r\n\x05token\x18\x02 \x01(\t\x12\x13\n\x0bvalid_until\x18\x03 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x04 \x01(\t2\xbc\x04\n\x0b\x64\x65viceAgent\x12N\n\tTestComms\x12\x1e.device_agent.TestCommsRequest\x1a\x1f.device_agent.TestCommsResponse\"\x00\x12`\n\x11GetChannelDetails\x12#.device_agent.ChannelDetailsRequest\x1a$.device_agent.ChannelDetailsResponse\"\x00\x12q\n\x16GetChannelSubscription\x12(.device_agent.ChannelSubscriptionRequest\x1a).device_agent.ChannelSubscriptionResponse\"\x00\x30\x01\x12Y\n\x0eWriteToChannel\x12!.device_agent.ChannelWriteRequest\x1a\".device_agent.ChannelWriteResponse\"\x00\x12Q\n\x0cGetDebugInfo\x12\x1e.device_agent.DebugInfoRequest\x1a\x1f.device_agent.DebugInfoResponse\"\x00\x12Z\n\x0fGetTempAPIToken\x12!.device_agent.TempAPITokenRequest\x1a\".device_agent.TempAPITokenResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'grpc_stubs.device_agent_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REQUESTHEADER']._serialized_start=47
  _globals['_REQUESTHEADER']._serialized_end=94
  _globals['_RESPONSEHEADER']._serialized_start=97
  _globals['_RESPONSEHEADER']._serialized_end=271
  _globals['_MESSAGEDETAILS']._serialized_start=273
  _globals['_MESSAGEDETAILS']._serialized_end=367
  _globals['_CHANNELDETAILS']._serialized_start=369
  _globals['_CHANNELDETAILS']._serialized_end=445
  _globals['_AGENTDETAILS']._serialized_start=447
  _globals['_AGENTDETAILS']._serialized_end=547
  _globals['_TESTCOMMSREQUEST']._serialized_start=549
  _globals['_TESTCOMMSREQUEST']._serialized_end=629
  _globals['_TESTCOMMSRESPONSE']._serialized_start=631
  _globals['_TESTCOMMSRESPONSE']._serialized_end=723
  _globals['_MESSAGEDETAILSREQUEST']._serialized_start=725
  _globals['_MESSAGEDETAILSREQUEST']._serialized_end=813
  _globals['_MESSAGEDETAILSRESPONSE']._serialized_start=816
  _globals['_MESSAGEDETAILSRESPONSE']._serialized_end=959
  _globals['_CHANNELDETAILSREQUEST']._serialized_start=961
  _globals['_CHANNELDETAILSREQUEST']._serialized_end=1051
  _globals['_CHANNELDETAILSRESPONSE']._serialized_start=1054
  _globals['_CHANNELDETAILSRESPONSE']._serialized_end=1197
  _globals['_CHANNELSUBSCRIPTIONREQUEST']._serialized_start=1199
  _globals['_CHANNELSUBSCRIPTIONREQUEST']._serialized_end=1294
  _globals['_CHANNELSUBSCRIPTIONRESPONSE']._serialized_start=1297
  _globals['_CHANNELSUBSCRIPTIONRESPONSE']._serialized_end=1509
  _globals['_CHANNELWRITEREQUEST']._serialized_start=1512
  _globals['_CHANNELWRITEREQUEST']._serialized_end=1695
  _globals['_DEBUGINFOREQUEST']._serialized_start=1697
  _globals['_DEBUGINFOREQUEST']._serialized_end=1760
  _globals['_CHANNELWRITERESPONSE']._serialized_start=1762
  _globals['_CHANNELWRITERESPONSE']._serialized_end=1859
  _globals['_DEBUGCHANNELSTATE']._serialized_start=1861
  _globals['_DEBUGCHANNELSTATE']._serialized_end=1970
  _globals['_DEBUGPENDINGMESSAGE']._serialized_start=1972
  _globals['_DEBUGPENDINGMESSAGE']._serialized_end=2087
  _globals['_DEBUGINFORESPONSE']._serialized_start=2090
  _globals['_DEBUGINFORESPONSE']._serialized_end=2399
  _globals['_TEMPAPITOKENREQUEST']._serialized_start=2401
  _globals['_TEMPAPITOKENREQUEST']._serialized_end=2467
  _globals['_TEMPAPITOKENRESPONSE']._serialized_start=2470
  _globals['_TEMPAPITOKENRESPONSE']._serialized_end=2601
  _globals['_DEVICEAGENT']._serialized_start=2604
  _globals['_DEVICEAGENT']._serialized_end=3176
# @@protoc_insertion_point(module_scope)
