# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpc_stubs/platform_iface.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fgrpc_stubs/platform_iface.proto\x12\x0eplatform_iface\"q\n\x0eResponseHeader\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x1a\n\rresponse_code\x18\x03 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07message\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\x10\n\x0e_response_codeB\n\n\x08_message\"#\n\x10TestCommsRequest\x12\x0f\n\x07message\x18\x01 \x01(\t\"^\n\x11TestCommsResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\x10\n\x08response\x18\x02 \x01(\t\"\x1a\n\x0cgetDIRequest\x12\n\n\x02\x64i\x18\x01 \x03(\x05\"T\n\rgetDIResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\n\n\x02\x64i\x18\x02 \x03(\x08\"\x1a\n\x0cgetAIRequest\x12\n\n\x02\x61i\x18\x01 \x03(\x05\"T\n\rgetAIResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\n\n\x02\x61i\x18\x02 \x03(\x02\"/\n\x13pulseCounterRequest\x12\n\n\x02\x64i\x18\x01 \x01(\x05\x12\x0c\n\x04\x65\x64ge\x18\x02 \x01(\t\"\xa7\x01\n\x14pulseCounterResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\x0f\n\x02\x64i\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\x08H\x01\x88\x01\x01\x12\x14\n\x07\x64t_secs\x18\x04 \x01(\x02H\x02\x88\x01\x01\x42\x05\n\x03_diB\x08\n\x06_valueB\n\n\x08_dt_secs\"\x1a\n\x0cgetDORequest\x12\n\n\x02\x64o\x18\x01 \x03(\x05\"T\n\rgetDOResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\n\n\x02\x64o\x18\x02 \x03(\x08\")\n\x0csetDORequest\x12\n\n\x02\x64o\x18\x01 \x03(\x05\x12\r\n\x05value\x18\x02 \x03(\x08\"T\n\rsetDOResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\n\n\x02\x64o\x18\x02 \x03(\x08\"T\n\x11scheduleDORequest\x12\n\n\x02\x64o\x18\x01 \x03(\x05\x12\r\n\x05value\x18\x02 \x03(\x08\x12\x16\n\ttime_secs\x18\x03 \x01(\x02H\x00\x88\x01\x01\x42\x0c\n\n_time_secs\"\x7f\n\x12scheduleDOResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\n\n\x02\x64o\x18\x02 \x03(\x08\x12\x16\n\ttime_secs\x18\x03 \x01(\x02H\x00\x88\x01\x01\x42\x0c\n\n_time_secs\"\x1a\n\x0cgetAORequest\x12\n\n\x02\x61o\x18\x01 \x03(\x05\"T\n\rgetAOResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\n\n\x02\x61o\x18\x02 \x03(\x02\"\x13\n\x11getIoTableRequest\"q\n\x12getIoTableResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\x15\n\x08io_table\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_io_table\")\n\x0csetAORequest\x12\n\n\x02\x61o\x18\x01 \x03(\x05\x12\r\n\x05value\x18\x03 \x03(\x02\"T\n\rsetAOResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\n\n\x02\x61o\x18\x02 \x03(\x02\"T\n\x11scheduleAORequest\x12\n\n\x02\x61o\x18\x01 \x03(\x05\x12\r\n\x05value\x18\x02 \x03(\x02\x12\x16\n\ttime_secs\x18\x03 \x01(\x02H\x00\x88\x01\x01\x42\x0c\n\n_time_secs\"\x7f\n\x12scheduleAOResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\n\n\x02\x61o\x18\x02 \x03(\x02\x12\x16\n\ttime_secs\x18\x03 \x01(\x02H\x00\x88\x01\x01\x42\x0c\n\n_time_secs\"\x1f\n\x0fgetValueRequest\x12\x0c\n\x04name\x18\x01 \x03(\t\"Z\n\x10getValueResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\r\n\x05value\x18\x02 \x03(\t\".\n\x0fsetValueRequest\x12\x0c\n\x04name\x18\x01 \x03(\t\x12\r\n\x05value\x18\x02 \x03(\t\"Z\n\x10setValueResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\r\n\x05value\x18\x02 \x03(\t\"\x18\n\x16getSystemStatusRequest\"\x9a\x03\n\x17getSystemStatusResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\x1a\n\rinput_voltage\x18\x02 \x01(\x02H\x00\x88\x01\x01\x12\x18\n\x0btemperature\x18\x03 \x01(\x02H\x01\x88\x01\x01\x12\x15\n\x08rtc_time\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x13\n\x06uptime\x18\x05 \x01(\x02H\x03\x88\x01\x01\x12\x18\n\x0bsystem_info\x18\x06 \x01(\tH\x04\x88\x01\x01\x12#\n\x16scheduled_startup_secs\x18\x07 \x01(\x05H\x05\x88\x01\x01\x12$\n\x17scheduled_shutdown_secs\x18\x08 \x01(\x05H\x06\x88\x01\x01\x42\x10\n\x0e_input_voltageB\x0e\n\x0c_temperatureB\x0b\n\t_rtc_timeB\t\n\x07_uptimeB\x0e\n\x0c_system_infoB\x19\n\x17_scheduled_startup_secsB\x1a\n\x18_scheduled_shutdown_secs\"\x1c\n\x1agetShutdownImmunityRequest\"\x84\x01\n\x1bgetShutdownImmunityResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\x1a\n\rimmunity_secs\x18\x02 \x01(\x05H\x00\x88\x01\x01\x42\x10\n\x0e_immunity_secs\">\n\x16scheduleStartupRequest\x12\x16\n\ttime_secs\x18\x01 \x01(\x02H\x00\x88\x01\x01\x42\x0c\n\n_time_secs\"x\n\x17scheduleStartupResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\x16\n\ttime_secs\x18\x02 \x01(\x02H\x00\x88\x01\x01\x42\x0c\n\n_time_secs\"?\n\x17scheduleShutdownRequest\x12\x16\n\ttime_secs\x18\x01 \x01(\x02H\x00\x88\x01\x01\x42\x0c\n\n_time_secs\"y\n\x18scheduleShutdownResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\x16\n\ttime_secs\x18\x02 \x01(\x02H\x00\x88\x01\x01\x42\x0c\n\n_time_secs\"\x0f\n\rrebootRequest\"I\n\x0erebootResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\"\x11\n\x0fshutdownRequest\"K\n\x10shutdownResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\"\x17\n\x15getTemperatureRequest\"{\n\x16getTemperatureResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\x18\n\x0btemperature\x18\x02 \x01(\x02H\x00\x88\x01\x01\x42\x0e\n\x0c_temperature\"\x18\n\x16getInputVoltageRequest\"t\n\x17getInputVoltageResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\x14\n\x07voltage\x18\x02 \x01(\x02H\x00\x88\x01\x01\x42\n\n\x08_voltage\"2\n\x13loadFirmwareRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0e\n\x06target\x18\x02 \x01(\t\"O\n\x14loadFirmwareResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\"$\n\x15loadBootloaderRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\"Q\n\x16loadBootloaderResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\"\x1b\n\x19getFirmwareVersionRequest\"f\n\x1agetFirmwareVersionResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\x0f\n\x07version\x18\x02 \x01(\t\"\x14\n\x12getLocationRequest\"\x84\x03\n\x13getLocationResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12\x15\n\x08latitude\x18\x02 \x01(\x02H\x00\x88\x01\x01\x12\x16\n\tlongitude\x18\x03 \x01(\x02H\x01\x88\x01\x01\x12\x17\n\naltitude_m\x18\x04 \x01(\x02H\x02\x88\x01\x01\x12\x17\n\naccuracy_m\x18\x05 \x01(\x02H\x03\x88\x01\x01\x12\x16\n\tspeed_mps\x18\x06 \x01(\x02H\x04\x88\x01\x01\x12\x18\n\x0bheading_deg\x18\x07 \x01(\x02H\x05\x88\x01\x01\x12\x16\n\tsat_count\x18\x08 \x01(\x05H\x06\x88\x01\x01\x12\x16\n\ttimestamp\x18\t \x01(\tH\x07\x88\x01\x01\x42\x0b\n\t_latitudeB\x0c\n\n_longitudeB\r\n\x0b_altitude_mB\r\n\x0b_accuracy_mB\x0c\n\n_speed_mpsB\x0e\n\x0c_heading_degB\x0c\n\n_sat_countB\x0c\n\n_timestamp\"\x14\n\x12syncRtcTimeRequest\"N\n\x13syncRtcTimeResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\"\x80\x01\n\x0b\x45ventDetail\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x05\x12\r\n\x05\x65vent\x18\x02 \x01(\t\x12\x0b\n\x03pin\x18\x03 \x01(\x05\x12\r\n\x05value\x18\x04 \x01(\t\x12\x0c\n\x04time\x18\x05 \x01(\x03\x12\x17\n\ncm4_online\x18\x06 \x01(\x08H\x00\x88\x01\x01\x42\r\n\x0b_cm4_online\"<\n\x10getEventsRequest\x12\x18\n\x0b\x65vents_from\x18\x01 \x01(\x03H\x00\x88\x01\x01\x42\x0e\n\x0c_events_from\"\xa7\x01\n\x11getEventsResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12+\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x1b.platform_iface.EventDetail\x12\x1a\n\revents_synced\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\x10\n\x0e_events_synced\"\x8b\x01\n\x12getDIEventsRequest\x12\x0b\n\x03pin\x18\x01 \x01(\x05\x12\x0e\n\x06rising\x18\x02 \x01(\x08\x12\x0f\n\x07\x66\x61lling\x18\x03 \x01(\x08\x12\x1d\n\x15include_system_events\x18\x04 \x01(\x08\x12\x18\n\x0b\x65vents_from\x18\x05 \x01(\x03H\x00\x88\x01\x01\x42\x0e\n\x0c_events_from\"\xa9\x01\n\x13getDIEventsResponse\x12\x37\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1e.platform_iface.ResponseHeader\x12+\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x1b.platform_iface.EventDetail\x12\x1a\n\revents_synced\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\x10\n\x0e_events_synced2\xbb\x13\n\rplatformIface\x12R\n\tTestComms\x12 .platform_iface.TestCommsRequest\x1a!.platform_iface.TestCommsResponse\"\x00\x12\x46\n\x05getDI\x12\x1c.platform_iface.getDIRequest\x1a\x1d.platform_iface.getDIResponse\"\x00\x12\x46\n\x05getAI\x12\x1c.platform_iface.getAIRequest\x1a\x1d.platform_iface.getAIResponse\"\x00\x12\x62\n\x11startPulseCounter\x12#.platform_iface.pulseCounterRequest\x1a$.platform_iface.pulseCounterResponse\"\x00\x30\x01\x12\x46\n\x05getDO\x12\x1c.platform_iface.getDORequest\x1a\x1d.platform_iface.getDOResponse\"\x00\x12\x46\n\x05setDO\x12\x1c.platform_iface.setDORequest\x1a\x1d.platform_iface.setDOResponse\"\x00\x12U\n\nscheduleDO\x12!.platform_iface.scheduleDORequest\x1a\".platform_iface.scheduleDOResponse\"\x00\x12\x46\n\x05getAO\x12\x1c.platform_iface.getAORequest\x1a\x1d.platform_iface.getAOResponse\"\x00\x12\x46\n\x05setAO\x12\x1c.platform_iface.setAORequest\x1a\x1d.platform_iface.setAOResponse\"\x00\x12U\n\nscheduleAO\x12!.platform_iface.scheduleAORequest\x1a\".platform_iface.scheduleAOResponse\"\x00\x12O\n\x08getValue\x12\x1f.platform_iface.getValueRequest\x1a .platform_iface.getValueResponse\"\x00\x12O\n\x08setValue\x12\x1f.platform_iface.setValueRequest\x1a .platform_iface.setValueResponse\"\x00\x12R\n\tgetEvents\x12 .platform_iface.getEventsRequest\x1a!.platform_iface.getEventsResponse\"\x00\x12X\n\x0bgetDIEvents\x12\".platform_iface.getDIEventsRequest\x1a#.platform_iface.getDIEventsResponse\"\x00\x12\x64\n\x0fgetSystemStatus\x12&.platform_iface.getSystemStatusRequest\x1a\'.platform_iface.getSystemStatusResponse\"\x00\x12\x64\n\x0fgetInputVoltage\x12&.platform_iface.getInputVoltageRequest\x1a\'.platform_iface.getInputVoltageResponse\"\x00\x12\x61\n\x0egetTemperature\x12%.platform_iface.getTemperatureRequest\x1a&.platform_iface.getTemperatureResponse\"\x00\x12U\n\ngetIoTable\x12!.platform_iface.getIoTableRequest\x1a\".platform_iface.getIoTableResponse\"\x00\x12X\n\x0bsyncRtcTime\x12\".platform_iface.syncRtcTimeRequest\x1a#.platform_iface.syncRtcTimeResponse\"\x00\x12X\n\x0bgetLocation\x12\".platform_iface.getLocationRequest\x1a#.platform_iface.getLocationResponse\"\x00\x12p\n\x13getShutdownImmunity\x12*.platform_iface.getShutdownImmunityRequest\x1a+.platform_iface.getShutdownImmunityResponse\"\x00\x12\x64\n\x0fscheduleStartup\x12&.platform_iface.scheduleStartupRequest\x1a\'.platform_iface.scheduleStartupResponse\"\x00\x12g\n\x10scheduleShutdown\x12\'.platform_iface.scheduleShutdownRequest\x1a(.platform_iface.scheduleShutdownResponse\"\x00\x12I\n\x06reboot\x12\x1d.platform_iface.rebootRequest\x1a\x1e.platform_iface.rebootResponse\"\x00\x12O\n\x08shutdown\x12\x1f.platform_iface.shutdownRequest\x1a .platform_iface.shutdownResponse\"\x00\x12[\n\x0cloadFirmware\x12#.platform_iface.loadFirmwareRequest\x1a$.platform_iface.loadFirmwareResponse\"\x00\x12\x61\n\x0eloadBootloader\x12%.platform_iface.loadBootloaderRequest\x1a&.platform_iface.loadBootloaderResponse\"\x00\x12m\n\x12getFirmwareVersion\x12).platform_iface.getFirmwareVersionRequest\x1a*.platform_iface.getFirmwareVersionResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'grpc_stubs.platform_iface_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_RESPONSEHEADER']._serialized_start=51
  _globals['_RESPONSEHEADER']._serialized_end=164
  _globals['_TESTCOMMSREQUEST']._serialized_start=166
  _globals['_TESTCOMMSREQUEST']._serialized_end=201
  _globals['_TESTCOMMSRESPONSE']._serialized_start=203
  _globals['_TESTCOMMSRESPONSE']._serialized_end=297
  _globals['_GETDIREQUEST']._serialized_start=299
  _globals['_GETDIREQUEST']._serialized_end=325
  _globals['_GETDIRESPONSE']._serialized_start=327
  _globals['_GETDIRESPONSE']._serialized_end=411
  _globals['_GETAIREQUEST']._serialized_start=413
  _globals['_GETAIREQUEST']._serialized_end=439
  _globals['_GETAIRESPONSE']._serialized_start=441
  _globals['_GETAIRESPONSE']._serialized_end=525
  _globals['_PULSECOUNTERREQUEST']._serialized_start=527
  _globals['_PULSECOUNTERREQUEST']._serialized_end=574
  _globals['_PULSECOUNTERRESPONSE']._serialized_start=577
  _globals['_PULSECOUNTERRESPONSE']._serialized_end=744
  _globals['_GETDOREQUEST']._serialized_start=746
  _globals['_GETDOREQUEST']._serialized_end=772
  _globals['_GETDORESPONSE']._serialized_start=774
  _globals['_GETDORESPONSE']._serialized_end=858
  _globals['_SETDOREQUEST']._serialized_start=860
  _globals['_SETDOREQUEST']._serialized_end=901
  _globals['_SETDORESPONSE']._serialized_start=903
  _globals['_SETDORESPONSE']._serialized_end=987
  _globals['_SCHEDULEDOREQUEST']._serialized_start=989
  _globals['_SCHEDULEDOREQUEST']._serialized_end=1073
  _globals['_SCHEDULEDORESPONSE']._serialized_start=1075
  _globals['_SCHEDULEDORESPONSE']._serialized_end=1202
  _globals['_GETAOREQUEST']._serialized_start=1204
  _globals['_GETAOREQUEST']._serialized_end=1230
  _globals['_GETAORESPONSE']._serialized_start=1232
  _globals['_GETAORESPONSE']._serialized_end=1316
  _globals['_GETIOTABLEREQUEST']._serialized_start=1318
  _globals['_GETIOTABLEREQUEST']._serialized_end=1337
  _globals['_GETIOTABLERESPONSE']._serialized_start=1339
  _globals['_GETIOTABLERESPONSE']._serialized_end=1452
  _globals['_SETAOREQUEST']._serialized_start=1454
  _globals['_SETAOREQUEST']._serialized_end=1495
  _globals['_SETAORESPONSE']._serialized_start=1497
  _globals['_SETAORESPONSE']._serialized_end=1581
  _globals['_SCHEDULEAOREQUEST']._serialized_start=1583
  _globals['_SCHEDULEAOREQUEST']._serialized_end=1667
  _globals['_SCHEDULEAORESPONSE']._serialized_start=1669
  _globals['_SCHEDULEAORESPONSE']._serialized_end=1796
  _globals['_GETVALUEREQUEST']._serialized_start=1798
  _globals['_GETVALUEREQUEST']._serialized_end=1829
  _globals['_GETVALUERESPONSE']._serialized_start=1831
  _globals['_GETVALUERESPONSE']._serialized_end=1921
  _globals['_SETVALUEREQUEST']._serialized_start=1923
  _globals['_SETVALUEREQUEST']._serialized_end=1969
  _globals['_SETVALUERESPONSE']._serialized_start=1971
  _globals['_SETVALUERESPONSE']._serialized_end=2061
  _globals['_GETSYSTEMSTATUSREQUEST']._serialized_start=2063
  _globals['_GETSYSTEMSTATUSREQUEST']._serialized_end=2087
  _globals['_GETSYSTEMSTATUSRESPONSE']._serialized_start=2090
  _globals['_GETSYSTEMSTATUSRESPONSE']._serialized_end=2500
  _globals['_GETSHUTDOWNIMMUNITYREQUEST']._serialized_start=2502
  _globals['_GETSHUTDOWNIMMUNITYREQUEST']._serialized_end=2530
  _globals['_GETSHUTDOWNIMMUNITYRESPONSE']._serialized_start=2533
  _globals['_GETSHUTDOWNIMMUNITYRESPONSE']._serialized_end=2665
  _globals['_SCHEDULESTARTUPREQUEST']._serialized_start=2667
  _globals['_SCHEDULESTARTUPREQUEST']._serialized_end=2729
  _globals['_SCHEDULESTARTUPRESPONSE']._serialized_start=2731
  _globals['_SCHEDULESTARTUPRESPONSE']._serialized_end=2851
  _globals['_SCHEDULESHUTDOWNREQUEST']._serialized_start=2853
  _globals['_SCHEDULESHUTDOWNREQUEST']._serialized_end=2916
  _globals['_SCHEDULESHUTDOWNRESPONSE']._serialized_start=2918
  _globals['_SCHEDULESHUTDOWNRESPONSE']._serialized_end=3039
  _globals['_REBOOTREQUEST']._serialized_start=3041
  _globals['_REBOOTREQUEST']._serialized_end=3056
  _globals['_REBOOTRESPONSE']._serialized_start=3058
  _globals['_REBOOTRESPONSE']._serialized_end=3131
  _globals['_SHUTDOWNREQUEST']._serialized_start=3133
  _globals['_SHUTDOWNREQUEST']._serialized_end=3150
  _globals['_SHUTDOWNRESPONSE']._serialized_start=3152
  _globals['_SHUTDOWNRESPONSE']._serialized_end=3227
  _globals['_GETTEMPERATUREREQUEST']._serialized_start=3229
  _globals['_GETTEMPERATUREREQUEST']._serialized_end=3252
  _globals['_GETTEMPERATURERESPONSE']._serialized_start=3254
  _globals['_GETTEMPERATURERESPONSE']._serialized_end=3377
  _globals['_GETINPUTVOLTAGEREQUEST']._serialized_start=3379
  _globals['_GETINPUTVOLTAGEREQUEST']._serialized_end=3403
  _globals['_GETINPUTVOLTAGERESPONSE']._serialized_start=3405
  _globals['_GETINPUTVOLTAGERESPONSE']._serialized_end=3521
  _globals['_LOADFIRMWAREREQUEST']._serialized_start=3523
  _globals['_LOADFIRMWAREREQUEST']._serialized_end=3573
  _globals['_LOADFIRMWARERESPONSE']._serialized_start=3575
  _globals['_LOADFIRMWARERESPONSE']._serialized_end=3654
  _globals['_LOADBOOTLOADERREQUEST']._serialized_start=3656
  _globals['_LOADBOOTLOADERREQUEST']._serialized_end=3692
  _globals['_LOADBOOTLOADERRESPONSE']._serialized_start=3694
  _globals['_LOADBOOTLOADERRESPONSE']._serialized_end=3775
  _globals['_GETFIRMWAREVERSIONREQUEST']._serialized_start=3777
  _globals['_GETFIRMWAREVERSIONREQUEST']._serialized_end=3804
  _globals['_GETFIRMWAREVERSIONRESPONSE']._serialized_start=3806
  _globals['_GETFIRMWAREVERSIONRESPONSE']._serialized_end=3908
  _globals['_GETLOCATIONREQUEST']._serialized_start=3910
  _globals['_GETLOCATIONREQUEST']._serialized_end=3930
  _globals['_GETLOCATIONRESPONSE']._serialized_start=3933
  _globals['_GETLOCATIONRESPONSE']._serialized_end=4321
  _globals['_SYNCRTCTIMEREQUEST']._serialized_start=4323
  _globals['_SYNCRTCTIMEREQUEST']._serialized_end=4343
  _globals['_SYNCRTCTIMERESPONSE']._serialized_start=4345
  _globals['_SYNCRTCTIMERESPONSE']._serialized_end=4423
  _globals['_EVENTDETAIL']._serialized_start=4426
  _globals['_EVENTDETAIL']._serialized_end=4554
  _globals['_GETEVENTSREQUEST']._serialized_start=4556
  _globals['_GETEVENTSREQUEST']._serialized_end=4616
  _globals['_GETEVENTSRESPONSE']._serialized_start=4619
  _globals['_GETEVENTSRESPONSE']._serialized_end=4786
  _globals['_GETDIEVENTSREQUEST']._serialized_start=4789
  _globals['_GETDIEVENTSREQUEST']._serialized_end=4928
  _globals['_GETDIEVENTSRESPONSE']._serialized_start=4931
  _globals['_GETDIEVENTSRESPONSE']._serialized_end=5100
  _globals['_PLATFORMIFACE']._serialized_start=5103
  _globals['_PLATFORMIFACE']._serialized_end=7594
# @@protoc_insertion_point(module_scope)
